| fourier.smooth | R Documentation |
A mgcv-style smooth constructor for Fourier bases, used internally
by tfb_spline() when bs = "fourier".
## S3 method for class 'fourier.smooth.spec'
smooth.construct(object, data, knots)
## S3 method for class 'fourier.smooth'
Predict.matrix(object, data)
object |
a fitted |
data |
a list containing the data vector for prediction. |
knots |
not used. |
a smooth specification object with the Fourier basis matrix X
and optional second-derivative penalty S.
a design matrix evaluated at the new data points.
# used internally via tfb_spline:
f <- c(sin(2 * pi * (0:100) / 100), cos(2 * pi * (0:100) / 100))
tf_smooth <- tfb_spline(f, bs = "fourier", k = 11)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.