in_range: Find out if values are inside given bounds

View source: R/utils.R

in_rangeR Documentation

Find out if values are inside given bounds

Description

in_range and its infix-equivalent ⁠%inr%⁠ return TRUE for all values in the numeric vector f that are within the range of values in r.

Usage

in_range(f, r)

f %inr% r

Arguments

f

a numeric vector.

r

numeric vector used to specify a range, only the minimum and maximum of r are used.

Value

a logical vector of the same length as f.

See Also

Other tidyfun utility functions: tf_arg(), tf_zoom()

Examples

in_range(1:10, c(3, 7))
1:10 %inr% c(3, 7)

tf documentation built on April 7, 2026, 5:07 p.m.