| in_range | R Documentation |
in_range and its infix-equivalent %inr% return TRUE for all values in
the numeric vector f that are within the range of values in r.
in_range(f, r)
f %inr% r
f |
a numeric vector. |
r |
numeric vector used to specify a range, only the minimum and maximum
of |
a logical vector of the same length as f.
Other tidyfun utility functions:
tf_arg(),
tf_zoom()
in_range(1:10, c(3, 7))
1:10 %inr% c(3, 7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.