| tf_minmax | R Documentation |
tf vectorsBy default, min, max, and range compute pointwise extremes (the
existing behaviour). When a depth argument is supplied, they instead return
the most extreme / most central observation according to the chosen depth.
For the default "MHI" depth this gives the lowest / highest function in an
up-down sense.
## S3 method for class 'tf'
min(..., na.rm = FALSE, depth = NULL)
## S3 method for class 'tf'
max(..., na.rm = FALSE, depth = NULL)
## S3 method for class 'tf'
range(..., na.rm = FALSE, depth = NULL)
... |
|
na.rm |
logical; passed on to the pointwise summary or used to filter
|
depth |
depth method to use. |
a tf object.
tf_depth(), rank.tf()
Other tidyfun ordering and ranking functions:
tf_depth(),
tf_order
x <- tf_rgp(5) + 1:5
# pointwise (default):
min(x)
max(x)
# depth-based:
min(x, depth = "MHI")
max(x, depth = "MHI")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.