| tfsummaries | R Documentation |
tf objects across argument valuesThese will return a tf object containing the respective functional
statistic. See tf_fwise() for scalar summaries
(e.g. tf_fmean for means, tf_fmax for max. values) of each entry
in a tf-vector.
## S3 method for class 'tf'
mean(x, ...)
## S3 method for class 'tf'
median(x, na.rm = FALSE, depth = "MBD", ...)
sd(x, na.rm = FALSE)
## Default S3 method:
sd(x, na.rm = FALSE)
## S3 method for class 'tf'
sd(x, na.rm = FALSE)
var(x, y = NULL, na.rm = FALSE, use)
## Default S3 method:
var(x, y = NULL, na.rm = FALSE, use)
## S3 method for class 'tf'
var(x, y = NULL, na.rm = FALSE, use)
## S3 method for class 'tf'
summary(object, ..., depth = "MBD")
x |
a |
... |
optional additional arguments. |
na.rm |
logical. Should missing values be removed? |
depth |
depth method used for computing the median and central region.
See |
y |
|
use |
an optional character string giving a
method for computing covariances in the presence
of missing values. This must be (an abbreviation of) one of the strings
|
object |
a |
a tf object with the computed result.
summary.tf returns a tf-vector with the mean function, the functional
median, the pointwise min and max of x, and the pointwise min and max
of the central half of the functions in x, as defined by the chosen
depth (default "MBD", see tf_depth()).
tf_fwise()
Other tidyfun summary functions:
fivenum(),
functionwise
set.seed(123)
x <- tf_rgp(1) * 1:5
mean(x)
median(x, depth = "pointwise")
sd(x)
var(x)
summary(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.